Learn R Programming

screenshot (version 0.9.2)

save_clipboard_image: Saves an image from the clipboard to a file

Description

This function works only on windows.

Usage

save_clipboard_image(path = "", reset_transparent = TRUE)

Value

The path to the saved image file.

Arguments

path

Optional path to save the image to. If not specified, a temporary file will be created.

reset_transparent

A logical. If true, the image of transparent color will be removed.

Examples

Run this code
if (FALSE) {
# Save the image from the clipboard to a file
save_clipboard_image("clipboard_image.png")
}

Run the code above in your browser using DataLab