powered by
This function works only on windows.
save_clipboard_image(path = "", reset_transparent = TRUE)
The path to the saved image file.
Optional path to save the image to. If not specified, a temporary file will be created.
A logical. If true, the image of transparent color will be removed.
if (FALSE) { # Save the image from the clipboard to a file save_clipboard_image("clipboard_image.png") }
Run the code above in your browser using DataLab